Crate bevy_koto

Crate bevy_koto 

bevy_koto

Plugins for Bevy that add support for scripting with Koto.

Re-exports

pub use koto;
pub use koto_color;
pub use koto_geometry;
pub use koto_random;

Modules

camera
Support for modifying properties of a Bevy camera
color
Support for working with Bevy colors in Koto scripts
entity
Support for mapping Koto objects to Bevy entities
geometry
2D geometry utilities for Koto
koto_plugins
See KotoPlugins
prelude
A collection of useful items to import when using bevy_koto
random
Random number utilities for Koto scripts
runtime
Support for adding a Koto runtime to a Bevy application
shape
Support for adding and updating 2D shapes in Koto scripts
text
Text support for bevy_koto
window
Window events for bevy_koto